==> qtjambi-help-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiHelp/QHelpSearchEngine_shell.h <==
#ifndef QHELPSEARCHENGINE_SHELL_H
#define QHELPSEARCHENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtHelp/qhelpsearchengine.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpair.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtHelp/qhelpenginecore.h>
#include <QtHelp/qhelpsearchquerywidget.h>
#include <QtHelp/qhelpsearchresultwidget.h>
#include <QtJambi/RegistryAPI>


class QHelpSearchEngine_shell : public QHelpSearchEngine, public QtJambiShellInterface
{
public:
    QHelpSearchEngine_shell(QHelpEngineCore* helpEngine0, QObject* parent1 = nullptr);
    ~QHelpSearchEngine_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QHelpSearchEngine_access : public QHelpSearchEngine
{
};

#endif // QHELPSEARCHENGINE_SHELL_H

==> qtjambi-help-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiHelp/QHelpSearchEngine_shell.h <==
#ifndef QHELPSEARCHENGINE_SHELL_H
#define QHELPSEARCHENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtHelp/qhelpsearchengine.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtHelp/qhelpenginecore.h>
#include <QtHelp/qhelpsearchquerywidget.h>
#include <QtHelp/qhelpsearchresultwidget.h>
#include <QtJambi/RegistryAPI>


class QHelpSearchEngine_shell : public QHelpSearchEngine, public QtJambiShellInterface
{
public:
    QHelpSearchEngine_shell(QHelpEngineCore* helpEngine0, QObject* parent1 = nullptr);
    ~QHelpSearchEngine_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QHelpSearchEngine_access : public QHelpSearchEngine
{
};

#endif // QHELPSEARCHENGINE_SHELL_H
